par_ai_core API documentation
Description: Par AI Core. This package provides a simple interface for interacting with various LLM providers. Created by Paul Robello probello@gmail.com.

# Package `par_ai_core`

Par AI Core. This package provides a simple interface for interacting with various LLM providers. Created by Paul Robello probello@gmail.com.

## Sub-modules

`par_ai_core.llm_config`

  Configuration and management of Language Learning Models (LLMs) …

`par_ai_core.llm_image_utils`

  Utilities for handling images with Language Learning Models (LLMs) …

`par_ai_core.llm_providers`

  LLM provider types and configurations …

`par_ai_core.llm_utils`

  Utilities for LLM (Large Language Model) setup and operations …

`par_ai_core.output_utils`

  Output formatting utilities for enhanced display and data presentation …

`par_ai_core.par_logging`

  Logging handler for Par AI Core using rich …

`par_ai_core.pricing_lookup`

  Pricing Lookup and Cost Calculation Module …

`par_ai_core.provider_cb_info`

  Callback Handler for tracking token usage, tool calling, and LLM interactions …

`par_ai_core.search_utils`

  Utilities for performing web searches across various platforms …

`par_ai_core.time_display`

  Time Display and Conversion Utilities …

`par_ai_core.user_agents`

  User Agent Generator Module …

`par_ai_core.utils`

  Various types, utility functions and decorators for the par_ai_core package …

`par_ai_core.web_tools`

  Web Tools Module …